# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/rules/picker.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from omni.pro.protos.common import base_pb2 as common_dot_base__pb2
from omni.pro.protos.v1.rules import category_pb2 as v1_dot_rules_dot_category__pb2
from omni.pro.protos.v1.rules import user_pb2 as v1_dot_rules_dot_user__pb2
from omni.pro.protos.v1.rules import warehouse_pb2 as v1_dot_rules_dot_warehouse__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x15v1/rules/picker.proto\x12 pro.omni.oms.api.v1.rules.picker\x1a\x11\x63ommon/base.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x18v1/rules/warehouse.proto\x1a\x13v1/rules/user.proto\x1a\x17v1/rules/category.proto"a\n\x0e\x43\x61tegoryValues\x12\x15\n\rfamily_doc_id\x18\x01 \x01(\t\x12\x12\n\ngroup_code\x18\x02 \x01(\t\x12\x16\n\x0e\x61ttribute_code\x18\x03 \x01(\t\x12\x0c\n\x04\x63ode\x18\x04 \x01(\t"\xf1\x04\n\x06Picker\x12\n\n\x02id\x18\x01 \x01(\t\x12\x32\n\x04user\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.v1.rules.user.User\x12\x41\n\twarehouse\x18\x03 \x01(\x0b\x32..pro.omni.oms.api.v1.rules.warehouse.Warehouse\x12@\n\ncategories\x18\x04 \x03(\x0b\x32,.pro.omni.oms.api.v1.rules.category.Category\x12,\n\x08\x63\x61n_pick\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12,\n\x08\x63\x61n_pack\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12+\n\x07\x63\x61n_out\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12+\n\x07\x63\x61n_int\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12*\n\x06\x63\x61n_in\x18\t \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12.\n\ncan_return\x18\n \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x0e\n\x06status\x18\x0b \x01(\t\x12*\n\x06\x61\x63tive\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x13\n\x0b\x65xternal_id\x18\r \x01(\t\x12?\n\x0cobject_audit\x18\x0e \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\xe1\x03\n\x13PickerCreateRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x14\n\x0cwarehouse_id\x18\x02 \x01(\x05\x12I\n\x0f\x63\x61tegory_values\x18\x03 \x03(\x0b\x32\x30.pro.omni.oms.api.v1.rules.picker.CategoryValues\x12,\n\x08\x63\x61n_pick\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12,\n\x08\x63\x61n_pack\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12+\n\x07\x63\x61n_out\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12+\n\x07\x63\x61n_int\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12*\n\x06\x63\x61n_in\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12.\n\ncan_return\x18\t \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x0e\n\x06status\x18\n \x01(\t\x12\x36\n\x07\x63ontext\x18\x0b \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x9b\x01\n\x14PickerCreateResponse\x12\x38\n\x06picker\x18\x01 \x01(\x0b\x32(.pro.omni.oms.api.v1.rules.picker.Picker\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xef\x02\n\x11PickerReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\t\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xd5\x01\n\x12PickerReadResponse\x12\x39\n\x07pickers\x18\x01 \x03(\x0b\x32(.pro.omni.oms.api.v1.rules.picker.Picker\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12I\n\x11response_standard\x18\x03 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\x87\x01\n\x13PickerUpdateRequest\x12\x38\n\x06picker\x18\x01 \x01(\x0b\x32(.pro.omni.oms.api.v1.rules.picker.Picker\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x9b\x01\n\x14PickerUpdateResponse\x12\x38\n\x06picker\x18\x01 \x01(\x0b\x32(.pro.omni.oms.api.v1.rules.picker.Picker\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"Y\n\x13PickerDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"a\n\x14PickerDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard2\x8d\x04\n\rPickerService\x12\x7f\n\x0cPickerCreate\x12\x35.pro.omni.oms.api.v1.rules.picker.PickerCreateRequest\x1a\x36.pro.omni.oms.api.v1.rules.picker.PickerCreateResponse"\x00\x12y\n\nPickerRead\x12\x33.pro.omni.oms.api.v1.rules.picker.PickerReadRequest\x1a\x34.pro.omni.oms.api.v1.rules.picker.PickerReadResponse"\x00\x12\x7f\n\x0cPickerUpdate\x12\x35.pro.omni.oms.api.v1.rules.picker.PickerUpdateRequest\x1a\x36.pro.omni.oms.api.v1.rules.picker.PickerUpdateResponse"\x00\x12\x7f\n\x0cPickerDelete\x12\x35.pro.omni.oms.api.v1.rules.picker.PickerDeleteRequest\x1a\x36.pro.omni.oms.api.v1.rules.picker.PickerDeleteResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.rules.picker_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_CATEGORYVALUES"]._serialized_start = 182
    _globals["_CATEGORYVALUES"]._serialized_end = 279
    _globals["_PICKER"]._serialized_start = 282
    _globals["_PICKER"]._serialized_end = 907
    _globals["_PICKERCREATEREQUEST"]._serialized_start = 910
    _globals["_PICKERCREATEREQUEST"]._serialized_end = 1391
    _globals["_PICKERCREATERESPONSE"]._serialized_start = 1394
    _globals["_PICKERCREATERESPONSE"]._serialized_end = 1549
    _globals["_PICKERREADREQUEST"]._serialized_start = 1552
    _globals["_PICKERREADREQUEST"]._serialized_end = 1919
    _globals["_PICKERREADRESPONSE"]._serialized_start = 1922
    _globals["_PICKERREADRESPONSE"]._serialized_end = 2135
    _globals["_PICKERUPDATEREQUEST"]._serialized_start = 2138
    _globals["_PICKERUPDATEREQUEST"]._serialized_end = 2273
    _globals["_PICKERUPDATERESPONSE"]._serialized_start = 2276
    _globals["_PICKERUPDATERESPONSE"]._serialized_end = 2431
    _globals["_PICKERDELETEREQUEST"]._serialized_start = 2433
    _globals["_PICKERDELETEREQUEST"]._serialized_end = 2522
    _globals["_PICKERDELETERESPONSE"]._serialized_start = 2524
    _globals["_PICKERDELETERESPONSE"]._serialized_end = 2621
    _globals["_PICKERSERVICE"]._serialized_start = 2624
    _globals["_PICKERSERVICE"]._serialized_end = 3149
# @@protoc_insertion_point(module_scope)
